==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Belge Ekle',
	'bouton_ajouter_image' => 'Resim Ekle',
	'bouton_ajouter_image_document' => 'Bir resim veya belge eklemek',

	// D
	'double_clic_inserer_doc' => 'Bu kısayolu metne eklemek için çift tıklayınız',

	// E
	'entree_dimensions' => 'Boyutlar :',
	'entree_titre_document' => 'Belge başlığı :',
	'entree_titre_image' => 'Resim başlığı :',

	// I
	'image_tourner_180' => '180° döndür',
	'image_tourner_droite' => '90° sağa döndür',
	'image_tourner_gauche' => '90° sola döndür',
	'info_document' => 'Belge',
	'info_document_indisponible' => 'Bu belge uygun (boşta) değil',
	'info_documents' => 'Belge',
	'info_inclusion_directe' => 'Direkt ekleme :',
	'info_inclusion_vignette' => 'İkon ekleme :',
	'info_installer_tous_documents' => 'Tüm belgeleri kur',
	'info_logo_max_taille' => 'Logolar @maxi@ dan daha küçük olmalıdır (bu dosyanın boyutu  @actuel@).',
	'info_portfolio' => 'Portföy',
	'info_referencer_doc_distant' => 'Internet üzerinde bir dokümana atıfta bulunmak :',
	'info_telecharger' => 'Bilgisayarınızdan indiriniz :',
	'item_autoriser_selectionner_date_en_ligne' => 'Her belgenin çevrimiçi yayınlanma tarihinin değiştirilmesine izin vermek',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Belgelerin tarihleri siteye eklendikleri tarihtir',

	// T
	'texte_documents_joints' => 'Makale ve/veya bölümlere doküman eklenmesine izin verebilirsiniz
    (dosya, resim, mültimedya, vb.)
     Bu dosyalar sonradan makalede atıf konusu olabilir 
     ya da ayrı olarak görüntülenebilirler. ', # MODIF
	'texte_documents_joints_2' => 'Bu ayar, makalelere doğrudan resim girilmesine engel değildir.', # MODIF
	'titre_documents_joints' => 'Ekteki dokümanlar',
	'tout_dossier_upload' => 'Tüm @upload@ dosyası',

	// U
	'upload_fichier_zip' => 'ZIP dosya',
	'upload_fichier_zip_texte' => 'Kurmayı önerdiğiniz dosya bir Zip dosya.',
	'upload_fichier_zip_texte2' => 'Bu dosyanın şu sorunu olabilir :',
	'upload_limit' => 'Bu dosya sunucuya göre fazla büyük ; yüklenmesine izin verilen en büyük dosya : <i>@max@</i>.',
	'upload_zip_conserver' => 'Açtıktan sonra arşiv dosyasını sakla', # MODIF
	'upload_zip_decompacter' => 'Açıldı ve içerdiği tüm elemanlar siteye kuruldu. Siteye kurulacak dosyalar şunlar :',
	'upload_zip_telquel' => 'Sıkıştırılmış ZIP arşivi olarak, olduğu gibi kurulmuş ;',
	'upload_zip_titrer' => 'Dosya isimlerine göre başlık ver'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Belge Ekle',
	'bouton_ajouter_image' => 'Resim Ekle',
	'bouton_ajouter_image_document' => 'Bir resim veya belge eklemek',

	// D
	'double_clic_inserer_doc' => 'Bu kısayolu metne eklemek için çift tıklayınız',

	// E
	'entree_dimensions' => 'Boyutlar :',
	'entree_titre_document' => 'Belge başlığı :',
	'entree_titre_image' => 'Resim başlığı :',

	// I
	'image_tourner_180' => '180° döndür',
	'image_tourner_droite' => '90° sağa döndür',
	'image_tourner_gauche' => '90° sola döndür',
	'info_document' => 'Belge',
	'info_document_indisponible' => 'Bu belge uygun (boşta) değil',
	'info_documents' => 'Belge',
	'info_inclusion_directe' => 'Direkt ekleme :',
	'info_inclusion_vignette' => 'İkon ekleme :',
	'info_installer_tous_documents' => 'Tüm belgeleri kur',
	'info_logo_max_taille' => 'Logolar @maxi@ dan daha küçük olmalıdır (bu dosyanın boyutu  @actuel@).',
	'info_portfolio' => 'Portföy',
	'info_referencer_doc_distant' => 'Internet üzerinde bir dokümana atıfta bulunmak :',
	'info_telecharger' => 'Bilgisayarınızdan indiriniz :',
	'item_autoriser_selectionner_date_en_ligne' => 'Her belgenin çevrimiçi yayınlanma tarihinin değiştirilmesine izin vermek',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Belgelerin tarihleri siteye eklendikleri tarihtir',

	// T
	'texte_documents_joints' => 'Makale ve/veya bölümlere doküman eklenmesine izin verebilirsiniz
    (dosya, resim, mültimedya, vb.)
     Bu dosyalar sonradan makalede atıf konusu olabilir 
     ya da ayrı olarak görüntülenebilirler. ', # MODIF
	'texte_documents_joints_2' => 'Bu ayar, makalelere doğrudan resim girilmesine engel değildir.', # MODIF
	'titre_documents_joints' => 'Ekteki dokümanlar',
	'tout_dossier_upload' => 'Tüm @upload@ dosyası',

	// U
	'upload_fichier_zip' => 'ZIP dosya',
	'upload_fichier_zip_texte' => 'Kurmayı önerdiğiniz dosya bir Zip dosya.',
	'upload_fichier_zip_texte2' => 'Bu dosyanın şu sorunu olabilir :',
	'upload_limit' => 'Bu dosya sunucuya göre fazla büyük ; yüklenmesine izin verilen en büyük dosya : <i>@max@</i>.',
	'upload_zip_conserver' => 'Açtıktan sonra arşiv dosyasını sakla', # MODIF
	'upload_zip_decompacter' => 'Açıldı ve içerdiği tüm elemanlar siteye kuruldu. Siteye kurulacak dosyalar şunlar :',
	'upload_zip_telquel' => 'Sıkıştırılmış ZIP arşivi olarak, olduğu gibi kurulmuş ;',
	'upload_zip_titrer' => 'Dosya isimlerine göre başlık ver',
];
